Rag.Pipeline.Context (rag v0.3.4)
View SourceContext passed between pipeline steps.
The context holds all intermediate results and state as a pipeline executes. Steps can read from and write to the context to pass data between stages.
Summary
Functions
Adds an error to the context.
Gets a step result from the context metadata.
Creates a new context with the given input.
Puts a value in the context metadata.
Puts a step result in the context metadata.
Types
Functions
Adds an error to the context.
Gets a step result from the context metadata.
Creates a new context with the given input.
Puts a value in the context metadata.
Puts a step result in the context metadata.